from setuptools import setup

setup(name='fsc_distributions',
      version='1.0',
      author='FarahS',
      description='Gaussian and binomial distribution classes',
      packages=['fsc_distributions'],
      zip_safe=False)
